# a density plot is good for visualizing the distribution of
# a continuous variable
#
# Key function:  geom_density()
# Alternative function:  stat_density
# Key arguments to customize the plot:
#             alpha, color, fill, linetype, size

# We'll also use this plot to look at other enhancements
# You can also add a line for the mean using the function
# geom_vline()
# notice that aes is used before any geom
# but if a geom involves defining some data (like a mean line), 
#    then that geom must have an aes inside the geom parentheses too!

a<-ggplot(wdata,aes(x=weight))
a + geom_density()
a + geom_density(color = "black", fill = "gray")+
  geom_vline(aes(xintercept=mean(weight)),
             color="#fc4e07", linetype = "dashed", size = 1)
a + 
  geom_vline(aes(xintercept=mean(weight)),
             color="#fc4e07", linetype = "dashed", size = 1) +
  geom_density(color = "black", fill = "gray")


# change color by groups
a + geom_density(aes(color=sex))

# use a semi-transparent fill:  alpha =0.4
a + geom_density(aes(fill=sex), alpha = 0.4)

# add mean lines and color by sex
library(plyr)
mu <- ddply(wdata, "sex", summarise, grp.mean=mean(weight))
head(mu)
a + geom_density(aes(color=sex), alpha=0.4) +
  geom_vline(data = mu, aes(xintercept = grp.mean, color = sex), linetype= "dashed")
a2 <- a + geom_density(aes(color=sex), alpha=0.4) +
  geom_vline(data = mu, aes(xintercept = grp.mean, color = sex), linetype= "dashed") + 
  theme_minimal()
a2
a2 +scale_color_manual(values=c("#999999","#e69f00"))
a2 + scale_color_brewer(palette="Paired")
a2 + scale_color_grey()
a2 + theme_linedraw()


# you can do the same for the fill.  Use scale_fill_manual, scale_fill_brewer, etc.

a + geom_density()
a + geom_histogram()
a + geom_area(stat="bin")
a + geom_area()
a + geom_bar()  # doesn't work
ggplot (wdata, aes(x=sex)) + geom_bar()  # this gives you a count

ggplot (wdata, aes(sex,weight)) + geom_bar(stat="identity")
