# last time, we plotted the density as the y-value of a histogram
a<-ggplot(wdata,aes(x=weight))
a+  geom_histogram(bins=50)
a+  geom_histogram(aes(y = ..density..),bins=50)

# but what if we want to see a histogram, and then ALSO a density
# superimposed ("layered") on top of it?  The discrete and continous?
a+  geom_histogram(aes(y = ..density..),color = "blue", fill = "yellow") +
  geom_density(alpha = 0.2, fill = "grey")
# notice that when you have layered graphics, good to use alpha
# notice that we kept the ..density.. for the y-axis for hist
# so both graphs can overlay meaningfully
# if you use the default of "count", only the histogram displays
a+  geom_histogram(color = "blue", fill ="yellow") +
  geom_density(alpha = 0.2, fill = "grey")
# notice: the y-axis says "count", so density plot doesn't display

# Now let's add grouping: color and fill are INSIDE the aes!!
a+  geom_histogram(aes(y = ..density..,color = sex, fill = sex),
alpha = 0.4, position = "identity") +
  geom_density(aes(color = sex), size =1)

# I don't like these colors, so let's change them
# We still want color = sex as part of the aes
# But we want the outline to be black
# Note that scale_color_manual is the outline applied
# to BOTH histogram and density
a+  geom_histogram(aes(y = ..density..,color = sex, fill = sex),
                   alpha = 0.4, position = "identity") +
  geom_density(aes(color = sex), size =1) +
  scale_color_manual(values=(c("black", "black")))

# I changed the outlines to be different for each sex
# I also changed the "size" param.  It's only part of geom_density!
a+  geom_histogram(aes(y = ..density..,color = sex, fill = sex),
                   alpha = 0.4, position = "identity") +
  geom_density(aes(color = sex), size =5) +
  scale_color_manual(values=(c("black", "blue")))

a+  geom_histogram(aes(y = ..density..,color = sex, fill = sex),
                   alpha = 0.4, position = "identity") +
  geom_density(aes(color = sex), size =1) +
  scale_color_manual(values=(c("black", "blue")))

# you can change the fill too.

# ECDF:  Empirical Cumulative Density Function
# You will often see with together with a histogram

a + stat_ecdf(geom = "point")  # points for each %-ile of observation
a + stat_ecdf(geom = "step")   # tiny line segments
# Notice the y=axis is cumulative % of the distribution
# There is no geom for ecdf.  But there is a stat supporting it.
# That's why the format for this plot is different.
a+  geom_histogram(aes(y = ..density..,color = sex, fill = sex),
                   alpha = 0.4, position = "identity") +
  geom_density(aes(color = sex), size =1) +
  scale_color_manual(values=(c("black", "blue"))) +
  stat_ecdf(geom = "step")
# even though the y-axis is "density", the scale is the same
# as for cumulative percentages, so it seems to work.  Yay!



