# plot = data + aesthetics + geometry
# we can recreate some of the plots that we created with RBase and qplot.
# Then, we'll see how "layering" works
# mostly one-variable plots, but also some scatter points, because
# they can demonstrate some cool stuff
library(ggplot2)
library(gridExtra)
# Basic scatter plot
ggplot(data=mtcars, aes(x=wt,y=mpg)) +
  geom_point()

# Change the point size, and shape
ggplot(mtcars, aes(x=wt, y=mpg)) +
  geom_point(size=3, shape=18)
# http://sape.inf.usi.ch/quick-reference/ggplot2/shape

# you can use aes_string, see:
#https://stackoverflow.com/questions/28897577/what-is-the-difference-between-aes-and-aes-string-ggplot2-in-r
# practically speaking, it makes no difference, and I've always seen aes.
# But just in case you run into it, here's aes_string:
ggplot(mtcars, aes_string(x="wt", y="mpg")) +
  geom_point(size = 2, shape = 23, color = "red")

# using the geom_density function
ggplot (wdata, aes(x=weight)) + geom_density()
ggplot (wdata, aes(x=weight)) + stat_density()
# and just to confuse things further:
ggplot(wdata) + geom_density(aes(x = weight))
ggplot(wdata) + stat_density(aes(x = weight))
# There's more than one way to skin a cat
# ggplot has "stat" functions that are "paired" with geoms
# It also has some default stats associated with some geoms
# For instance, geom_bar has a default stat of count.
# A bar plot can act like a histogram in this case.
# The y-axis is frequency.

# cyl is a factor.  You can see the count of how many records have a cyl value of 4, 6 or 8
# Look at the geom_bar below:
ggplot (mtcars, aes(cyl)) + geom_bar()

# What if you wanted to know how many mpg, in total, did cars get (by cyl)
# I think this is a stupid question, but I wanted to stay with the same dataset.
# The point is, if you want something other than count, you have to change the stat
ggplot (mtcars, aes(cyl, mpg)) + geom_bar()  # error
ggplot (mtcars, aes(cyl, mpg)) + geom_bar(stat="identity")
# Note, we added a y aes (because we want the y axis to relect mpg)
# and we changed stat to "identity", meaning, the actual values of mpg,
# not just the count of the # of records having a certain cyl value


# let's start with creating a graphic object upon which we can build layers
a<-  ggplot(wdata, aes(x=weight))
a  # this doesn't plot anything, because we didn't add any geoms yet

# area plot ( a continuous analog of a stacked bar chart)
a + geom_area(stat="bin",
              color="black", fill = "#00afbb")

# compare bar plots and area plots
par(mfrow=c(1,2)) #this doesn't work with ggplot
# use require(gridExra)  or library(gridExtra)
# unless you are installing a package from within a function, they're the same
data("diamonds")
diamonds
p<-ggplot(diamonds,aes(x=price,fill=cut))
p1=p+geom_bar(stat="bin")  # bins are grouped ranges of x values
# the results tell you to use the binwidth parameter for better bin width
# however, geom_bar no longer has a binwidth param
# you have to use geom_histogram.  In case you thought they were really different...
p2=p+geom_area(stat="bin")
grid.arrange(p1,p2)
# or side by side
grid.arrange(p1,p2, ncol=2)
p3=p+geom_bar(stat="count") 
p3
p4=p+geom_histogram(stat="bin", binwidth=500)
p4

